@@ -20,8 +20,8 @@ use base 'PDF::Builder::Basic::PDF::String';
 use strict;
 use warnings;
 
-our $VERSION = '3.022'; # VERSION
-my $LAST_UPDATE = '3.022'; # manually update whenever code is changed
+our $VERSION = '3.026'; # VERSION
+our $LAST_UPDATE = '3.026'; # manually update whenever code is changed
 
 =head1 NAME
 
@@ -31,20 +31,32 @@ B<true> or B<false>
 
 =head1 METHODS
 
-=head2 $b->convert($str)
+=head2 convert
+
+    $b->convert($str)
+
+=over
 
 Converts a string into the string which will be stored.
 
+=back
+
 =cut
 
 sub convert {
     return $_[1] eq 'true';
 }
 
-=head2 $b->as_pdf()
+=head2 as_pdf
+
+    $b->as_pdf()
+
+=over
 
 Converts the value to a PDF output form.
 
+=back
+
 =cut
 
 sub as_pdf {
