@@ -5,11 +5,11 @@ use base 'PDF::Builder::Resource';
 use strict;
 use warnings;
 
-our $VERSION = '3.022'; # VERSION
-my $LAST_UPDATE = '3.018'; # manually update whenever code is changed
+our $VERSION = '3.026'; # VERSION
+our $LAST_UPDATE = '3.026'; # manually update whenever code is changed
 
 use Compress::Zlib;
-use Encode qw(:all);
+#use Encode qw(:all);
 use PDF::Builder::Basic::PDF::Utils;
 use PDF::Builder::Util;
 use Scalar::Util qw(weaken);
@@ -20,12 +20,16 @@ PDF::Builder::Resource::BaseFont - Base class for font resources
 
 =head1 METHODS
 
+=head2 new
+
+    $font = PDF::Builder::Resource::BaseFont->new($pdf, $name)
+
 =over
 
-=item $font = PDF::Builder::Resource::BaseFont->new($pdf, $name)
-
 Return a font resource object.
 
+=back
+
 =cut
 
 sub new {
@@ -50,10 +54,16 @@ sub data {
     return $_[0]->{' data'}; 
 }
 
-=item $descriptor = $font->descrByData()
+=head2 descrByData
+
+    $descriptor = $font->descrByData()
+
+=over
 
 Return the font's FontDescriptor key structure based on the font's data.
 
+=back
+
 =cut
 
 sub descrByData {
@@ -152,82 +162,116 @@ sub tounicodemap {
     return $self;
 }
 
-=back
-
 =head1 FONT-MANAGEMENT RELATED METHODS
 
+=head2 fontname
+
+    $name = $font->fontname()
+
 =over
 
-=item $name = $font->fontname()
-
 Return the font's name (a.k.a. display name).
 
+=back
+
 =cut
 
 sub fontname { 
     return $_[0]->data()->{'fontname'}; 
 }
 
-=item $name = $font->altname()
+=head2 altname
+
+    $name = $font->altname()
+
+=over
 
 Return the font's alternative name (a.k.a. Windows name for a PostScript font).
 
+=back
+
 =cut
 
 sub altname { 
     return $_[0]->data()->{'altname'}; 
 }
 
-=item $name = $font->subname()
+=head2 subname
+
+    $name = $font->subname()
+
+=over
 
 Return the font's subname (a.k.a. font variant).
 
+=back
+
 =cut
 
 sub subname { 
     return $_[0]->data()->{'subname'}; 
 }
 
-=item $name = $font->apiname()
+=head2 apiname
+
+    $name = $font->apiname()
+
+=over
 
 Return the font's name to be used internally (should be equal to $font->name()).
 
+=back
+
 =cut
 
 sub apiname { 
     return $_[0]->data()->{'apiname'}; 
 }
 
-=item $issymbol = $font->issymbol()
+=head2 issymbol
+
+    $issymbol = $font->issymbol()
+
+=over
 
 Return the font's symbol flag (i.e., is this a symbol font).
 
+=back
+
 =cut
 
 sub issymbol { 
     return $_[0]->data()->{'issymbol'}; 
 }
 
-=item $iscff = $font->iscff()
+=head2 iscff
+
+    $iscff = $font->iscff()
+
+=over
 
 Return the font's Compact Font Format flag.
 
+=back
+
 =cut
 
 sub iscff { 
     return $_[0]->data()->{'iscff'}; 
 }
 
-=back
-
 =head1 TYPOGRAPHY-RELATED METHODS
 
+=head2 fontbbox
+
+    ($llx,$lly, $urx,$ury) = $font->fontbbox()
+
 =over
 
-=item ($llx,$lly, $urx,$ury) = $font->fontbbox()
-
 Return the font's bounding box.
 
+=back
+
 =cut
 
 sub fontbbox { 
@@ -239,50 +283,80 @@ sub fontbbox {
     return @bbox;
 }
 
-=item $capheight = $font->capheight()
+=head2 capheight
+
+    $capheight = $font->capheight()
+
+=over
 
 Return the font's capheight value.
 
+=back
+
 =cut
 
 sub capheight { 
     return $_[0]->data()->{'capheight'}; 
 }
 
-=item $xheight = $font->xheight()
+=head2 xheight
+
+    $xheight = $font->xheight()
+
+=over
 
 Return the font's xheight value.
 
+=back
+
 =cut
 
 sub xheight { 
     return $_[0]->data()->{'xheight'}; 
 }
 
-=item $missingwidth = $font->missingwidth()
+=head2 missingwidth
+
+    $missingwidth = $font->missingwidth()
+
+=over
 
 Return the font's missingwidth value.
 
+=back
+
 =cut
 
 sub missingwidth { 
     return $_[0]->data()->{'missingwidth'}; 
 }
 
-=item $maxwidth = $font->maxwidth()
+=head2 maxwidth
+
+    $maxwidth = $font->maxwidth()
+
+=over
 
 Return the font's maxwidth value.
 
+=back
+
 =cut
 
 sub maxwidth { 
     return $_[0]->data()->{'maxwidth'}; 
 }
 
-=item $avgwidth = $font->avgwidth()
+=head2 avgwidth
+
+    $avgwidth = $font->avgwidth()
+
+=over
 
 Return the font's avgwidth (average width) value.
 
+=back
+
 =cut
 
 sub avgwidth {
@@ -351,39 +425,63 @@ sub avgwidth {
     return int($aw);
 }
 
-=item $flags = $font->flags()
+=head2 flags
+
+    $flags = $font->flags()
+
+=over
 
 Return the font's flags value.
 
+=back
+
 =cut
 
 sub flags { 
     return $_[0]->data()->{'flags'}; 
 }
 
-=item $stemv = $font->stemv()
+=head2 stemv
+
+    $stemv = $font->stemv()
+
+=over
 
 Return the font's stemv value.
 
+=back
+
 =cut
 
 sub stemv { 
     return $_[0]->data()->{'stemv'}; 
 }
 
-=item $stemh = $font->stemh()
+=head2 stemh
+
+    $stemh = $font->stemh()
+
+=over
 
 Return the font's stemh value.
 
+=back
+
 =cut
 
 sub stemh { 
     return $_[0]->data()->{'stemh'}; 
 }
 
-=item $italicangle = $font->italicangle()
+=head2 italicangle
 
-Return the font's italicangle value.
+    $italicangle = $font->italicangle()
+
+=over
+
+Return the font's italicangle (slant, obliqueness) value.
+
+=back
 
 =cut
 
@@ -391,76 +489,114 @@ sub italicangle {
     return $_[0]->data()->{'italicangle'}; 
 }
 
-=item $isfixedpitch = $font->isfixedpitch()
+=head2 isfixedpitch
+
+    $isfixedpitch = $font->isfixedpitch()
+
+=over
 
 Return the font's isfixedpitch flag.
 
+=back
+
 =cut
 
 sub isfixedpitch { 
     return $_[0]->data()->{'isfixedpitch'}; 
 }
 
-=item $underlineposition = $font->underlineposition()
+=head2 underlineposition
+
+    $underlineposition = $font->underlineposition()
+
+=over
 
 Return the font's underlineposition value.
 
+=back
+
 =cut
 
 sub underlineposition { 
     return $_[0]->data()->{'underlineposition'}; 
 }
 
-=item $underlinethickness = $font->underlinethickness()
+=head2 underlinethickness
+
+    $underlinethickness = $font->underlinethickness()
+
+=over
 
 Return the font's underlinethickness value.
 
+=back
+
 =cut
 
 sub underlinethickness { 
     return $_[0]->data()->{'underlinethickness'}; 
 }
 
-=item $ascender = $font->ascender()
+=head2 ascender
+
+    $ascender = $font->ascender()
+
+=over
 
 Return the font's ascender value.
 
+=back
+
 =cut
 
 sub ascender { 
     return $_[0]->data()->{'ascender'}; 
 }
 
-=item $descender = $font->descender()
+=head2 descender
+
+    $descender = $font->descender()
+
+=over
 
 Return the font's descender value.
 
+=back
+
 =cut
 
 sub descender { 
     return $_[0]->data()->{'descender'}; 
 }
 
-=back
-
 =head1 GLYPH-RELATED METHODS
 
-=over 4
+=head2 glyphNames
 
-=item @names = $font->glyphNames()
+    @names = $font->glyphNames()
+
+=over
 
 Return the defined glyph names of the font.
 
+=back
+
 =cut
 
 sub glyphNames { 
     return keys %{$_[0]->data()->{'wx'}}; 
 }
 
-=item $glNum = $font->glyphNum()
+=head2 glyphNum
+
+    $glNum = $font->glyphNum()
+
+=over
 
 Return the number of defined glyph names of the font.
 
+=back
+
 =cut
 
 sub glyphNum { 
@@ -469,10 +605,16 @@ sub glyphNum {
     return scalar keys %{$_[0]->data()->{'wx'}}; 
 }
 
-=item $uni = $font->uniByGlyph($char)
+=head2 uniByGlyph
+
+    $uni = $font->uniByGlyph($char)
+
+=over
 
 Return the unicode by glyph name.
 
+=back
+
 =cut
 
 sub uniByGlyph { 
@@ -481,10 +623,16 @@ sub uniByGlyph {
     return $_[0]->data()->{'n2u'}->{$_[1]}; 
 }
 
-=item $uni = $font->uniByEnc($char)
+=head2 uniByEnc
+
+    $uni = $font->uniByEnc($char)
+
+=over
 
 Return the Unicode by the font's encoding map.
 
+=back
+
 =cut
 
 sub uniByEnc { 
@@ -495,30 +643,48 @@ sub uniByEnc {
     return $uni;
 }
 
-=item $uni = $font->uniByMap($char)
+=head2 uniByMap
+
+    $uni = $font->uniByMap($char)
+
+=over
 
 Return the Unicode by the font's default map.
 
+=back
+
 =cut
 
 sub uniByMap { 
     return $_[0]->data()->{'uni'}->[$_[1]]; 
 }
 
-=item $char = $font->encByGlyph($glyph)
+=head2 encByGlyph
+
+    $char = $font->encByGlyph($glyph)
+
+=over
 
 Return the character by the given glyph name of the font's encoding map.
 
+=back
+
 =cut
 
 sub encByGlyph { 
     return $_[0]->data()->{'n2e'}->{$_[1]} || 0; 
 }
 
-=item $char = $font->encByUni($uni)
+=head2 encByUni
+
+    $char = $font->encByUni($uni)
+
+=over
 
 Return the character by the given Unicode of the font's encoding map.
 
+=back
+
 =cut
 
 sub encByUni { 
@@ -527,65 +693,101 @@ sub encByUni {
 	   0; 
 }
 
-=item $char = $font->mapByGlyph($glyph)
+=head2 mapByGlyph
+
+    $char = $font->mapByGlyph($glyph)
+
+=over
 
 Return the character by the given glyph name of the font's default map.
 
+=back
+
 =cut
 
 sub mapByGlyph { 
     return $_[0]->data()->{'n2c'}->{$_[1]} || 0; 
 }
 
-=item $char = $font->mapByUni($uni)
+=head2 mapByUni
+
+    $char = $font->mapByUni($uni)
+
+=over
 
 Return the character by the given Unicode of the font's default map.
 
+=back
+
 =cut
 
 sub mapByUni { 
     return $_[0]->data()->{'u2c'}->{$_[1]} || 0; 
 }
 
-=item $name = $font->glyphByUni($unicode)
+=head2 glyphByUni
+
+    $name = $font->glyphByUni($unicode)
+
+=over
 
 Return the glyph's name by the font's Unicode map.
-B<BEWARE:> non-standard glyph-names are mapped onto
+B<CAUTION:> non-standard glyph-names are mapped onto
 the ms-symbol area (0xF000).
 
+=back
+
 =cut
 
 sub glyphByUni { 
     return $_[0]->data()->{'u2n'}->{$_[1]} || '.notdef'; 
 }
 
-=item $name = $font->glyphByEnc($char)
+=head2 glyphByEnc
+
+    $name = $font->glyphByEnc($char)
+
+=over
 
 Return the glyph's name by the font's encoding map.
 
+=back
+
 =cut
 
 sub glyphByEnc {
     return $_[0]->data()->{'e2n'}->[$_[1]];
 }
 
-=item $name = $font->glyphByMap($char)
+=head2 glyphByMap
+
+    $name = $font->glyphByMap($char)
+
+=over
 
 Return the glyph's name by the font's default map.
 
+=back
+
 =cut
 
 sub glyphByMap { 
     return $_[0]->data()->{'char'}->[$_[1]]; 
 }
 
-=item $width = $font->wxByGlyph($glyph)
+=head2 wxByGlyph
+
+    $width = $font->wxByGlyph($glyph)
+
+=over
 
 Return the glyph's width.
 This is a value, that when divided by 1000 and multiplied by
 the font size (height in points), gives the advance width to the
 next character's start. Typically, the width will be under 1000.
 
+=back
+
 =cut
 
 sub wxByGlyph {
@@ -604,13 +806,19 @@ sub wxByGlyph {
     return $width;
 }
 
-=item $width = $font->wxByUni($uni)
+=head2 wxByUni
+
+    $width = $font->wxByUni($uni)
+
+=over
 
 Return the Unicode character's width.
 This is a value, that when divided by 1000 and multiplied by
 the font size (height in points), gives the advance width to the
 next character's start. Typically, the width will be under 1000.
 
+=back
+
 =cut
 
 sub wxByUni {
@@ -625,13 +833,19 @@ sub wxByUni {
     return $width;
 }
 
-=item $width = $font->wxByEnc($char)
+=head2 wxByEnc
+
+    $width = $font->wxByEnc($char)
+
+=over
 
 Return the character's width based on the current encoding.
 This is a value, that when divided by 1000 and multiplied by
 the font size (height in points), gives the advance width to the
 next character's start. Typically, the width will be under 1000.
 
+=back
+
 =cut
 
 sub wxByEnc {
@@ -648,11 +862,17 @@ sub wxByEnc {
     return $width;
 }
 
-=item $flag = $font->wxMissingByEnc($char)
+=head2 wxMissingByEnc
+
+    $flag = $font->wxMissingByEnc($char)
+
+=over
 
 Return true if the character's width (based on the current encoding) is
 supplied by "missing width" of font.
 
+=back
+
 =cut
 
 sub wxMissingByEnc {
@@ -664,13 +884,19 @@ sub wxMissingByEnc {
     return !defined($width);
 }
 
-=item $width = $font->wxByMap($char)
+=head2 wxByMap
+
+    $width = $font->wxByMap($char)
+
+=over
 
 Return the character's width based on the font's default encoding.
 This is a value, that when divided by 1000 and multiplied by
 the font size (height in points), gives the advance width to the
 next character's start. Typically, the width will be under 1000.
 
+=back
+
 =cut
 
 sub wxByMap {
@@ -686,12 +912,18 @@ sub wxByMap {
     return $width;
 }
 
-=item $wd = $font->width($text)
+=head2 width
 
-Return the width of $text as if it were at size 1.
-B<BEWARE:> works only correctly if a proper Perl string
+    $wd = $font->width($text)
+
+=over
+
+Return the width of $text as if it were at font size 1 (unscaled).
+B<CAUTION:> works correctly only if a proper Perl string
 is used, either in native or UTF-8 format (check utf8-flag).
 
+=back
+
 =cut
 
 sub width {
@@ -716,10 +948,16 @@ sub width {
     return $width;
 }
 
-=item @widths = $font->width_array($text)
+=head2 width_array
+
+    @widths = $font->width_array($text)
+
+=over
 
 Return (as an array) the widths of the words in $text as if they were at size 1.
 
+=back
+
 =cut
 
 sub width_array {
@@ -730,16 +968,16 @@ sub width_array {
     return @widths;
 }
 
-=back
+=head2 utfByStr
 
-=head1 STRING METHODS
+    $utf8string = $font->utfByStr($string)
 
 =over
 
-=item $utf8string = $font->utfByStr($string)
-
 Return the utf8-string from string based on the font's encoding map.
 
+=back
+
 =cut
 
 sub utfByStr {
@@ -750,10 +988,16 @@ sub utfByStr {
     return $string;
 }
 
-=item $string = $font->strByUtf($utf8_string)
+=head2 strByUtf
+
+    $string = $font->strByUtf($utf8_string)
+
+=over
 
 Return the encoded string from utf8-string based on the font's encoding map.
 
+=back
+
 =cut
 
 sub strByUtf {
@@ -764,10 +1008,16 @@ sub strByUtf {
     return $utf8_string;
 }
 
-=item $pdf_string = $font->textByStr($string)
+=head2 textByStr
+
+    $pdf_string = $font->textByStr($string)
+
+=over
 
 Return a properly formatted representation of $string for use in the PDF.
 
+=back
+
 =cut
 
 sub textByStr {
@@ -783,11 +1033,17 @@ sub textByStr {
     return $text;
 }
 
-=item $pdf_string = $font->textByStrKern($string)
+=head2 textByStrKern
+
+    $pdf_string = $font->textByStrKern($string)
+
+=over
 
 Return a properly formatted representation of $string, with kerning, 
 for use in the PDF.
 
+=back
+
 =cut
 
 sub textByStrKern {
@@ -844,8 +1100,4 @@ sub isvirtual {
     return; 
 }
 
-=back
-
-=cut
-
 1;
