@@ -5,8 +5,8 @@ use base 'PDF::Builder::Resource::XObject::Form::Hybrid';
 use strict;
 use warnings;
 
-our $VERSION = '3.022'; # VERSION
-my $LAST_UPDATE = '3.010'; # manually update whenever code is changed
+our $VERSION = '3.026'; # VERSION
+our $LAST_UPDATE = '3.026'; # manually update whenever code is changed
 
 use PDF::Builder::Util;
 use PDF::Builder::Basic::PDF::Utils;
@@ -17,30 +17,45 @@ PDF::Builder::Resource::XObject::Form::BarCode - Base class for one-dimensional
 
 =head1 METHODS
 
+=head2 new
+
+    $barcode = PDF::Builder::Resource::XObject::Form::BarCode->new($pdf, %options)
+
 =over
 
-=item $barcode = PDF::Builder::Resource::XObject::Form::BarCode->new($pdf, %options)
-
 Creates a barcode form resource.
 
+=back
+
 =cut
 
 sub new {
     my ($class, $pdf, %options) = @_;
+    # copy dashed option names to preferred undashed names
+    if (defined $options{'-font'} && !defined $options{'font'}) { $options{'font'} = delete($options{'-font'}); }
+    if (defined $options{'-umzn'} && !defined $options{'umzn'}) { $options{'umzn'} = delete($options{'-umzn'}); }
+    if (defined $options{'-lmzn'} && !defined $options{'lmzn'}) { $options{'lmzn'} = delete($options{'-lmzn'}); }
+    if (defined $options{'-zone'} && !defined $options{'zone'}) { $options{'zone'} = delete($options{'-zone'}); }
+    if (defined $options{'-quzn'} && !defined $options{'quzn'}) { $options{'quzn'} = delete($options{'-quzn'}); }
+    if (defined $options{'-ofwt'} && !defined $options{'ofwt'}) { $options{'ofwt'} = delete($options{'-ofwt'}); }
+    if (defined $options{'-fnsz'} && !defined $options{'fnsz'}) { $options{'fnsz'} = delete($options{'-fnsz'}); }
+    if (defined $options{'-spcr'} && !defined $options{'spcr'}) { $options{'spcr'} = delete($options{'-spcr'}); }
+    if (defined $options{'-mils'} && !defined $options{'mils'}) { $options{'mils'} = delete($options{'-mils'}); }
+    if (defined $options{'-color'} && !defined $options{'color'}) { $options{'color'} = delete($options{'-color'}); }
 
     my $self = $class->SUPER::new($pdf);
 
-    $self->{' bfont'} = $options{'-font'};
+    $self->{' bfont'} = $options{'font'};
 
-    $self->{' umzn'} = $options{'-umzn'} || 0;    # (u)pper (m)ending (z)o(n)e
-    $self->{' lmzn'} = $options{'-lmzn'} || 0;    # (l)ower (m)ending (z)o(n)e
-    $self->{' zone'} = $options{'-zone'} || 0;    # barcode height
-    $self->{' quzn'} = $options{'-quzn'} || 0;    # (qu)iet (z)o(n)e
-    $self->{' ofwt'} = $options{'-ofwt'} || 0.01; # (o)ver(f)low (w)id(t)h
-    $self->{' fnsz'} = $options{'-fnsz'};         # (f)o(n)t(s)i(z)e
-    $self->{' spcr'} = $options{'-spcr'} || '';   # (sp)a(c)e(r) between chars in label
-    $self->{' mils'} = $options{'-mils'} || 1000/72; # single barcode unit width. 1 mil = 1/1000 of one inch. 1000/72 - for backward compatibility
-    $self->{' color'} = $options{'-color'} || 'black'; # barcode color
+    $self->{' umzn'} = $options{'umzn'} || 0;    # (u)pper (m)ending (z)o(n)e
+    $self->{' lmzn'} = $options{'lmzn'} || 0;    # (l)ower (m)ending (z)o(n)e
+    $self->{' zone'} = $options{'zone'} || 0;    # barcode height
+    $self->{' quzn'} = $options{'quzn'} || 0;    # (qu)iet (z)o(n)e
+    $self->{' ofwt'} = $options{'ofwt'} || 0.01; # (o)ver(f)low (w)id(t)h
+    $self->{' fnsz'} = $options{'fnsz'};         # (f)o(n)t(s)i(z)e
+    $self->{' spcr'} = $options{'spcr'} || '';   # (sp)a(c)e(r) between chars in label
+    $self->{' mils'} = $options{'mils'} || 1000/72; # single barcode unit width. 1 mil = 1/1000 of one inch. 1000/72 - for backward compatibility
+    $self->{' color'} = $options{'color'} || 'black'; # barcode color
 
     return $self;
 }
@@ -106,11 +121,14 @@ sub drawbar {
                 $y0 = $self->{' quzn'} + $self->{' lmzn'};
                 $y1 = $self->{' quzn'} + $self->{' lmzn'} + $self->{' zone'} + $self->{' umzn'};
                 $y_label   = $self->{' quzn'};
+                if ($self->{' fnsz'} and $self->{' lmzn'} < $self->{' fnsz'}) {
+                    $y_label -= $self->{' fnsz'} * 0.8 - $self->{' lmzn'};
+                }
                 $font_size = $self->{' fnsz'} || $self->{' lmzn'};
             } elsif ($bar =~ /[a-z]/) {
                 $y0 = $self->{' quzn'};
                 $y1 = $self->{' quzn'} + $self->{' lmzn'} + $self->{' zone'} + $self->{' umzn'};
-                $y_label   = $self->{' quzn'} + $self->{' lmzn'} + $self->{' zone'} + $self->{' umzn'};
+                $y_label   = $self->{' quzn'} + $self->{' lmzn'} + $self->{' zone'} + $self->{' umzn'} + 2;
                 $font_size = $self->{' fnsz'} || $self->{' umzn'};
             } elsif ($bar =~ /[A-Z]/) {
                 $y0 = $self->{' quzn'};
@@ -165,7 +183,15 @@ sub drawbar {
     return;
 }
 
-=item $width = $barcode->width()
+=head2 width
+
+    $width = $barcode->width()
+
+=over
+
+Returns the width of the bar code.
+
+=back
 
 =cut
 
@@ -175,18 +201,23 @@ sub width {
     return $self->{' w'};
 }
 
-=item $height = $barcode->height()
+=head2 height
+
+    $height = $barcode->height()
+
+=over
+
+Returns the height of the bar code.
+
+=back
 
 =cut
 
+
 sub height {
     my $self = shift;
 
     return $self->{' h'};
 }
 
-=back
-
-=cut
-
 1;
